@@ -1,4 +1,5 @@
 #!/bin/bash
+# shellcheck disable=SC2155
 
 _TOTAL_TESTS_COUNT=0
 
@@ -99,12 +100,24 @@ function console_results::render_result() {
 }
 
 function console_results::print_execution_time() {
-  if [[ $BASHUNIT_SHOW_EXECUTION_TIME == false ]]; then
+  if ! env::is_show_execution_time_enabled; then
     return
   fi
 
-  _EXECUTION_TIME=$(clock::total_runtime_in_milliseconds)
-  printf "${_COLOR_BOLD}%s${_COLOR_DEFAULT}\n" "Time taken: ${_EXECUTION_TIME} ms"
+  local time=$(printf "%.0f" "$(clock::total_runtime_in_milliseconds)")
+
+  if [[ "$time" -lt 1000 ]]; then
+    printf "${_COLOR_BOLD}%s${_COLOR_DEFAULT}\n" \
+      "Time taken: $time ms"
+    return
+  fi
+
+  local time_in_seconds=$(( time / 1000 ))
+  local remainder_ms=$(( time % 1000 ))
+  local formatted_seconds=$(printf "%.2f" "$time_in_seconds.$remainder_ms")
+
+  printf "${_COLOR_BOLD}%s${_COLOR_DEFAULT}\n" \
+    "Time taken: $formatted_seconds s"
 }
 
 function console_results::print_successful_test() {
@@ -121,7 +134,7 @@ function console_results::print_successful_test() {
   fi
 
   local full_line=$line
-  if [[ $BASHUNIT_SHOW_EXECUTION_TIME == true ]]; then
+  if env::is_show_execution_time_enabled; then
     full_line="$(printf "%s\n" "$(str::rpad "$line" "$duration ms")")"
   fi
 
